@@ -1,5 +1,5 @@
 from .message import *
 from .message_list import *
 from .connection import *
-from .client import *
-from .server import *
+from .message_client import *
+from .message_server import *
